@@ -1,6 +1,7 @@
 from wincam.camera import Camera
-from wincam.dxcam import DXCamera, EncodingProperties, VideoEncodingQuality
+from wincam.dxcam import DXCamera
 from wincam.logger import Logger
+from wincam.native import EncodingProperties, VideoEncodingQuality
 from wincam.throttle import FpsThrottle
 from wincam.timer import Timer
 
